@@ -1,25 +1,11 @@
 /*
- * "$Id: file.h 1488 2006-05-31 19:00:02Z mike $"
+ * Filename definitions for HTMLDOC, a HTML document processing program.
  *
- *   Filename definitions for HTMLDOC, a HTML document processing program.
+ * Copyright 2011, 2014 by Michael R Sweet.
+ * Copyright 1997-2010 by Easy Software Products.  All rights reserved.
  *
- *   Copyright 1997-2005 by Easy Software Products.
- *
- *   These coded instructions, statements, and computer programs are the
- *   property of Easy Software Products and are protected by Federal
- *   copyright law.  Distribution and use rights are outlined in the file
- *   "COPYING.txt" which should have been included with this file.  If this
- *   file is missing or damaged please contact Easy Software Products
- *   at:
- *
- *       Attn: ESP Licensing Information
- *       Easy Software Products
- *       44141 Airport View Drive, Suite 204
- *       Hollywood, Maryland 20636-3142 USA
- *
- *       Voice: (301) 373-9600
- *       EMail: info@easysw.com
- *         WWW: http://www.easysw.com
+ * This program is free software.  Distribution and use rights are outlined in
+ * the file "COPYING".
  */
 
 #ifndef _FILE_H_
@@ -49,7 +35,7 @@ extern const char	*file_find(const char *path, const char *s);
 extern char		*file_gets(char *buf, int buflen, FILE *fp);
 extern const char	*file_localize(const char *filename, const char *newcwd);
 extern const char	*file_method(const char *s);
-extern void		file_nolocal();
+extern void		file_nolocal(void);
 extern void		file_proxy(const char *url);
 extern void		file_referer(const char *referer);
 extern const char	*file_rlookup(const char *filename);
@@ -61,7 +47,3 @@ extern FILE		*file_temp(char *name, int len);
 #  endif /* __cplusplus */
 
 #endif /* !_FILE_H_ */
-
-/*
- * End of "$Id: file.h 1488 2006-05-31 19:00:02Z mike $".
- */
