@@ -1,29 +1,12 @@
 //
-// "$Id: license.cxx 1439 2005-10-28 20:32:59Z mike $"
+// GUI license dialog routines for HTMLDOC, an HTML document processing
+// program.
 //
-//   GUI license dialog routines for HTMLDOC, an HTML document processing
-//   program.
-//
-//   Copyright 1997-2005 by Easy Software Products.
-//
-//   These coded instructions, statements, and computer programs are the
-//   property of Easy Software Products and are protected by Federal
-//   copyright law.  Distribution and use rights are outlined in the file
-//   "COPYING.txt" which should have been included with this file.  If this
-//   file is missing or damaged please contact Easy Software Products
-//   at:
-//
-//       Attn: ESP Licensing Information
-//       Easy Software Products
-//       44141 Airport View Drive, Suite 204
-//       Hollywood, Maryland 20636 USA
-//
-//       Voice: (301) 373-9600
-//       EMail: info@easysw.com
-//         WWW: http://www.easysw.com
-//
-// Contents:
+// Copyright 2011-2020 by Michael R Sweet.
+// Copyright 1997-2010 by Easy Software Products.  All rights reserved.
 //
+// This program is free software.  Distribution and use rights are outlined in
+// the file "COPYING".
 //
 
 #include "htmldoc.h"
@@ -64,30 +47,28 @@ GUI::showLicenseCB(void)
 
   // Create the window complete with the license agreement and
   // button to add a new license...
-  dialog = new Fl_Window(480, 480, "HTMLDOC " SVERSION " License");
+  dialog = new Fl_Window(640, 480, "HTMLDOC " SVERSION " License");
   dialog->set_modal();
   dialog->hotspot(dialog);
 
-  group = new Fl_Group(10, 10, 460, 425, "HTMLDOC " SVERSION " License");
+  group = new Fl_Group(10, 10, 620, 425, "HTMLDOC " SVERSION " License");
   group->align((Fl_Align)(FL_ALIGN_LEFT | FL_ALIGN_TOP | FL_ALIGN_INSIDE));
   group->box(FL_THIN_UP_BOX);
   group->labelcolor(FL_BLUE);
   group->labelfont(FL_HELVETICA_BOLD);
   group->labelsize(18);
 
-  box = new Fl_Box(20, 45, 440, 110,
-    "You are using the free, unsupported version of HTMLDOC which is "
-    "provided under the terms of the GNU General Public License shown "
-    "below. Commercial versions of HTMLDOC, which financially "
-    "support the continued development of HTMLDOC, may be purchased at the "
-    "following URL:\n"
-    "\n"
-    "                http://www.easysw.com/htmldoc/"
+  box = new Fl_Box(20, 45, 600, 110,
+    "Copyright © 2011-2022 by Michael R Sweet.\n\n"
+    "HTMLDOC is provided under the terms of the GNU General Public License and "
+    "comes with absolutely no warranty.  Please report problems on the Github "
+    "issues page at:\n\n"
+    "    https://github.com/michaelrsweet/htmldoc/issues\n"
   );
 
   box->align((Fl_Align)(FL_ALIGN_TOP_LEFT | FL_ALIGN_INSIDE | FL_ALIGN_WRAP));
 
-  help = new Fl_Help_View(20, 190, 440, 235, "Software License Agreement:");
+  help = new Fl_Help_View(20, 190, 600, 235, "Software License Agreement:");
   help->align(FL_ALIGN_TOP_LEFT);
   help->value(
     "<h3>GNU GENERAL PUBLIC LICENSE</h3>\n"
@@ -331,11 +312,73 @@ GUI::showLicenseCB(void)
     "PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE "
     "POSSIBILITY OF SUCH DAMAGES. "
     "<h4>END OF TERMS AND CONDITIONS</h4>\n"
+    "<h4>How to Apply These Terms to Your New Programs</h3>\n"
+    "\n"
+    "<p>If you develop a new program, and you want it to be of the greatest\n"
+    "possible use to the public, the best way to achieve this is to make it\n"
+    "free software which everyone can redistribute and change under these terms.\n"
+    "\n"
+    "<p>To do so, attach the following notices to the program.  It is safest\n"
+    "to attach them to the start of each source file to most effectively\n"
+    "convey the exclusion of warranty; and each file should have at least\n"
+    "the \"copyright\" line and a pointer to where the full notice is found.\n"
+    "\n"
+    "<pre>\n"
+    "<var>one line to give the program's name and an idea of what it does.</var>\n"
+    "Copyright (C) <var>yyyy</var>  <var>name of author</var>\n"
+    "\n"
+    "This program is free software; you can redistribute it and/or\n"
+    "modify it under the terms of the GNU General Public License\n"
+    "as published by the Free Software Foundation; either version 2\n"
+    "of the License, or (at your option) any later version.\n"
+    "\n"
+    "This program is distributed in the hope that it will be useful,\n"
+    "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
+    "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
+    "GNU General Public License for more details.\n"
+    "\n"
+    "You should have received a copy of the GNU General Public License\n"
+    "along with this program; if not, write to the Free Software\n"
+    "Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.\n"
+    "</pre>\n"
+    "\n"
+    "<p>Also add information on how to contact you by electronic and paper mail.\n"
+    "\n"
+    "<p>If the program is interactive, make it output a short notice like this\n"
+    "when it starts in an interactive mode:\n"
+    "\n"
+    "<pre>\n"
+    "Gnomovision version 69, Copyright (C) <var>year</var> <var>name of author</var>\n"
+    "Gnomovision comes with ABSOLUTELY NO WARRANTY; for details\n"
+    "type `show w'.  This is free software, and you are welcome\n"
+    "to redistribute it under certain conditions; type `show c' \n"
+    "for details.\n"
+    "</pre>\n"
+    "\n"
+    "<p>The hypothetical commands <samp>`show w'</samp> and <samp>`show c'</samp> should show\n"
+    "the appropriate parts of the General Public License.  Of course, the\n"
+    "commands you use may be called something other than <samp>`show w'</samp> and\n"
+    "<samp>`show c'</samp>; they could even be mouse-clicks or menu items--whatever\n"
+    "suits your program.\n"
+    "\n"
+    "<p>You should also get your employer (if you work as a programmer) or your\n"
+    "school, if any, to sign a \"copyright disclaimer\" for the program, if\n"
+    "necessary.  Here is a sample; alter the names:\n"
+    "\n"
+    "<pre>\n"
+    "Yoyodyne, Inc., hereby disclaims all copyright\n"
+    "interest in the program `Gnomovision'\n"
+    "(which makes passes at compilers) written \n"
+    "by James Hacker.\n"
+    "\n"
+    "<var>signature of Ty Coon</var>, 1 April 1989\n"
+    "Ty Coon, President of Vice\n"
+    "</pre>\n"
   );
 
   group->end();
 
-  button = new Fl_Button(405, 445, 65, 25, "Close");
+  button = new Fl_Button(565, 445, 65, 25, "Close");
   button->callback((Fl_Callback *)closeLicenseCB);
 
   // Show the window and wait...
@@ -362,7 +405,3 @@ closeLicenseCB(Fl_Widget *w)		// I - Close button
 
 
 #endif // HAVE_LIBFLTK
-
-//
-// End of "$Id: license.cxx 1439 2005-10-28 20:32:59Z mike $".
-//
