@@ -35,10 +35,14 @@ format_number(int  n,		/* I - Number */
 		  "",	"x",	"xx",	"xxx",	"xl",
 		  "l",	"lx",	"lxx",	"lxxx",	"xc"
 		},
-		*hundreds[10] =	/* Roman numerals, 100-900 */
+		*hundreds[30] =	/* Roman numerals, 100-2900 */
 		{
-		  "",	"c",	"cc",	"ccc",	"cd",
-		  "d",	"dc",	"dcc",	"dccc",	"cm"
+		  "",    "c",    "cc",    "ccc",    "cd",
+		  "d",   "dc",   "dcc",   "dccc",   "cm",
+		  "m",   "mc",   "cc",    "ccc",    "cd",
+		  "m",   "mdc",  "mdcc",  "mdccc",  "mcm",
+		  "mm",  "mmc",  "mmcc",  "mmccc",  "mmcd",
+		  "mmd", "mmdc", "mmdcc", "mmdccc", "mmcm"
 		};
   static const char *ONES[10] =	/* Roman numerals, 0-9 */
 		{
@@ -50,10 +54,14 @@ format_number(int  n,		/* I - Number */
 		  "",	"X",	"XX",	"XXX",	"XL",
 		  "L",	"LX",	"LXX",	"LXXX",	"XC"
 		},
-		*HUNDREDS[10] =	/* Roman numerals, 100-900 */
+		*HUNDREDS[30] =	/* Roman numerals, 100-2900 */
 		{
-		  "",	"C",	"CC",	"CCC",	"CD",
-		  "D",	"DC",	"DCC",	"DCCC",	"CM"
+		  "",    "C",    "CC",    "CCC",    "CD",
+		  "D",   "DC",   "DCC",   "DCCC",   "CM",
+		  "M",   "MC",   "CC",    "CCC",    "CD",
+		  "M",   "MDC",  "MDCC",  "MDCCC",  "MCM",
+		  "MM",  "MMC",  "MMCC",  "MMCCC",  "MMCD",
+		  "MMD", "MMDC", "MMDCC", "MMDCCC", "MMCM"
 		};
   static char	buffer[1024];	/* String buffer */
 
@@ -65,18 +73,20 @@ format_number(int  n,		/* I - Number */
 	break;
 
     case 'a' :
-        if (n >= (26 * 26))
-	  buffer[0] = '\0';
-        else if (n > 26)
+        if (n > (26 * 26))
+          n = (n % (26 * 26)) + 1;
+
+        if (n > 26)
           snprintf(buffer, sizeof(buffer), "%c%c", 'a' + (n / 26) - 1, 'a' + (n % 26) - 1);
         else
           snprintf(buffer, sizeof(buffer), "%c", 'a' + n - 1);
         break;
 
     case 'A' :
-        if (n >= (26 * 26))
-	  buffer[0] = '\0';
-        else if (n > 26)
+        if (n > (26 * 26))
+          n = (n % (26 * 26)) + 1;
+
+        if (n > 26)
           snprintf(buffer, sizeof(buffer), "%c%c", 'A' + (n / 26) - 1, 'A' + (n % 26) - 1);
         else
           snprintf(buffer, sizeof(buffer), "%c", 'A' + n - 1);
@@ -87,17 +97,17 @@ format_number(int  n,		/* I - Number */
         break;
 
     case 'i' :
-        if (n >= 1000)
-	  buffer[0] = '\0';
-	else
-          snprintf(buffer, sizeof(buffer), "%s%s%s", hundreds[n / 100], tens[(n / 10) % 10], ones[n % 10]);
+        if (n >= 3000)
+          n = ((n - 3000) % 2999) + 1;
+
+	snprintf(buffer, sizeof(buffer), "%s%s%s", hundreds[n / 100], tens[(n / 10) % 10], ones[n % 10]);
         break;
 
     case 'I' :
-        if (n >= 1000)
-	  buffer[0] = '\0';
-	else
-          snprintf(buffer, sizeof(buffer), "%s%s%s", HUNDREDS[n / 100], TENS[(n / 10) % 10], ONES[n % 10]);
+        if (n >= 3000)
+          n = ((n - 3000) % 2999) + 1;
+
+	snprintf(buffer, sizeof(buffer), "%s%s%s", HUNDREDS[n / 100], TENS[(n / 10) % 10], ONES[n % 10]);
         break;
   }
 
